//Here we imported nessary packages from D3 
import {
  select,
  csv, 
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
// Here assigned all the varibales 
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //Here its is title of the page
  const title = 'Number of car units sold';
  
  const xValue = d => d.soldyear; //display dates for x axis
  const xAxisLabel = 'sold Year';
// Here assigning the  data for plotting yaxis dataset
  const yValue = d => d.units;
  const yAxisLabel = 'units';
  
  const margin = { top: 40, right: 40, bottom: 80, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //The  set of values for xscale
    .domain(extent(data, xValue)) //It returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) 
     .nice(0);// The round values out
  
  const yScale = scaleLinear()
  // The set of values for yscale
    .domain([0, max(data, yValue )])// It returns the minimum and maximum value in an array from the given array using natural order.
    .range([innerHeight, 0])
  	.nice();// The round values out
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  //  Here we assigning xscale dimensions
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  // Here  we assigning yscale dimensions
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
 //  Here assigning label for Y axis 
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -50)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  // Here is the X axis allignment lable
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'red')
      .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  // Allignment of title code here
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
  		.attr('x', 220)
  		.attr('font-style','bold')
      .text(title);
};
//Here we import the data from SVG file
csv('https://gist.githubusercontent.com/Sheshidharreddy/6f6812ee5cb9e9693e275fa99cc7de6d/raw/b11c7486fbf02b1e984dfef26ad1c0862b24f2d2/years.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.units = +d.units;
      d.soldyear = new Date(d.soldyear)
    });
  console.log(data)
    render(data);
  });